_**by Edgar Allan Poe**  
(published 1849)_

    

     I NEVER knew anyone so keenly alive to a joke as the king was. He seemed to live only for joking. To tell a good story of the joke kind, and to tell it well, was the surest road to his favor. Thus it happened that his seven ministers were all noted for their accomplishments as jokers. They all took after the king, too, in being large, corpulent, oily men, as well as inimitable jokers. Whether people grow fat by joking, or whether there is something in fat itself which predisposes to a joke, I have never been quite able to determine; but certain it is that a lean joker is a rara avis in terris.  
  
About the refinements, or, as he called them, the 'ghost' of wit, the king troubled himself very little. He had an especial admiration for breadth in a jest, and would often put up with length, for the sake of it. Over-niceties wearied him. He would have preferred Rabelais' 'Gargantua' to the 'Zadig' of Voltaire: and, upon the whole, practical jokes suited his taste far better than verbal ones.  
  
At the date of my narrative, professing jesters had not altogether gone out of fashion at court. Several of the great continental 'powers' still retain their 'fools,' who wore motley, with caps and bells, and who were expected to be always ready with sharp witticisms, at a moment's notice, in consideration of the crumbs that fell from the royal table.  
  
Our king, as a matter of course, retained his 'fool.' The fact is, he required something in the way of folly -- if only to counterbalance the heavy wisdom of the seven wise men who were his ministers -- not to mention himself.  
  
His fool, or professional jester, was not only a fool, however. His value was trebled in the eyes of the king, by the fact of his being also a dwarf and a cripple. Dwarfs were as common at court, in those days, as fools; and many monarchs would have found it difficult to get through their days (days are rather longer at court than elsewhere) without both a jester to laugh with, and a dwarf to laugh at. But, as I have already observed, your jesters, in ninety-nine cases out of a hundred, are fat, round, and unwieldy -- so that it was no small source of self-gratulation with our king that, in Hop-Frog (this was the fool's name), he possessed a triplicate treasure in one person.  
  
I believe the name 'Hop-Frog' was not that given to the dwarf by his sponsors at baptism, but it was conferred upon him, by general consent of the several ministers, on account of his inability to walk as other men do. In fact, Hop-Frog could only get along by a sort of interjectional gait -- something between a leap and a wriggle -- a movement that afforded illimitable amusement, and of course consolation, to the king, for (notwithstanding the protuberance of his stomach and a constitutional swelling of the head) the king, by his whole court, was accounted a capital figure.  
  
But although Hop-Frog, through the distortion of his legs, could move only with great pain and difficulty along a road or floor, the prodigious muscular power which nature seemed to have bestowed upon his arms, by way of compensation for deficiency in the lower limbs, enabled him to perform many feats of wonderful dexterity, where trees or ropes were in question, or any thing else to climb. At such exercises he certainly much more resembled a squirrel, or a small monkey, than a frog.  
  
I am not able to say, with precision, from what country Hop-Frog originally came. It was from some barbarous region, however, that no person ever heard of -- a vast distance from the court of our king. Hop-Frog, and a young girl very little less dwarfish than himself (although of exquisite proportions, and a marvellous dancer), had been forcibly carried off from their respective homes in adjoining provinces, and sent as presents to the king, by one of his ever-victorious generals.  
  
Under these circumstances, it is not to be wondered at that a close intimacy arose between the two little captives. Indeed, they soon became sworn friends. Hop-Frog, who, although he made a great deal of sport, was by no means popular, had it not in his power to render Trippetta many services; but she, on account of her grace and exquisite beauty (although a dwarf), was universally admired and petted; so she possessed much influence; and never failed to use it, whenever she could, for the benefit of Hop-Frog.  
  
On some grand state occasion -- I forgot what -- the king determined to have a masquerade, and whenever a masquerade or any thing of that kind, occurred at our court, then the talents, both of Hop-Frog and Trippetta were sure to be called into play. Hop-Frog, in especial, was so inventive in the way of getting up pageants, suggesting novel characters, and arranging costumes, for masked balls, that nothing could be done, it seems, without his assistance.  
  
The night appointed for the fete had arrived. A gorgeous hall had been fitted up, under Trippetta's eye, with every kind of device which could possibly give eclat to a masquerade. The whole court was in a fever of expectation. As for costumes and characters, it might well be supposed that everybody had come to a decision on such points. Many had made up their minds (as to what roles they should assume) a week, or even a month, in advance; and, in fact, there was not a particle of indecision anywhere -- except in the case of the king and his seven minsters. Why they hesitated I never could tell, unless they did it by way of a joke. More probably, they found it difficult, on account of being so fat, to make up their minds. At all events, time flew; and, as a last resort they sent for Trippetta and Hop-Frog.  
  
When the two little friends obeyed the summons of the king they found him sitting at his wine with the seven members of his cabinet council; but the monarch appeared to be in a very ill humor. He knew that Hop-Frog was not fond of wine, for it excited the poor cripple almost to madness; and madness is no comfortable feeling. But the king loved his practical jokes, and took pleasure in forcing Hop-Frog to drink and (as the king called it) 'to be merry.'  
  
"Come here, Hop-Frog," said he, as the jester and his friend entered the room; "swallow this bumper to the health of your absent friends, [here Hop-Frog sighed,] and then let us have the benefit of your invention. We want characters -- characters, man -- something novel -- out of the way. We are wearied with this everlasting sameness. Come, drink! the wine will brighten your wits."  
  
Hop-Frog endeavored, as usual, to get up a jest in reply to these advances from the king; but the effort was too much. It happened to be the poor dwarf's birthday, and the command to drink to his 'absent friends' forced the tears to his eyes. Many large, bitter drops fell into the goblet as he took it, humbly, from the hand of the tyrant.  
  
"Ah! ha! ha!" roared the latter, as the dwarf reluctantly drained the beaker. -- "See what a glass of good wine can do! Why, your eyes are shining already!"  
  
Poor fellow! his large eyes gleamed, rather than shone; for the effect of wine on his excitable brain was not more powerful than instantaneous. He placed the goblet nervously on the table, and looked round upon the company with a half -- insane stare. They all seemed highly amused at the success of the king's 'joke.'  
  
"And now to business," said the prime minister, a very fat man.  
  
"Yes," said the King; "Come lend us your assistance. Characters, my fine fellow; we stand in need of characters -- all of us -- ha! ha! ha!" and as this was seriously meant for a joke, his laugh was chorused by the seven.  
  
Hop-Frog also laughed although feebly and somewhat vacantly.  
  
"Come, come," said the king, impatiently, "have you nothing to suggest?"  
  
"I am endeavoring to think of something novel," replied the dwarf, abstractedly, for he was quite bewildered by the wine.  
  
"Endeavoring!" cried the tyrant, fiercely; "what do you mean by that? Ah, I perceive. You are Sulky, and want more wine. Here, drink this!" and he poured out another goblet full and offered it to the cripple, who merely gazed at it, gasping for breath.  
  
"Drink, I say!" shouted the monster, "or by the fiends-"  
  
The dwarf hesitated. The king grew purple with rage. The courtiers smirked. Trippetta, pale as a corpse, advanced to the monarch's seat, and, falling on her knees before him, implored him to spare her friend.  
  
The tyrant regarded her, for some moments, in evident wonder at her audacity. He seemed quite at a loss what to do or say -- how most becomingly to express his indignation. At last, without uttering a syllable, he pushed her violently from him, and threw the contents of the brimming goblet in her face.  
  
The poor girl got up the best she could, and, not daring even to sigh, resumed her position at the foot of the table.  
  
There was a dead silence for about half a minute, during which the falling of a leaf, or of a feather, might have been heard. It was interrupted by a low, but harsh and protracted grating sound which seemed to come at once from every corner of the room.  
  
"What -- what -- what are you making that noise for?" demanded the king, turning furiously to the dwarf.  
  
The latter seemed to have recovered, in great measure, from his intoxication, and looking fixedly but quietly into the tyrant's face, merely ejaculated:  
  
"I -- I? How could it have been me?"  
  
"The sound appeared to come from without," observed one of the courtiers. "I fancy it was the parrot at the window, whetting his bill upon his cage-wires."  
  
"True," replied the monarch, as if much relieved by the suggestion; "but, on the honor of a knight, I could have sworn that it was the gritting of this vagabond's teeth."  
  
Hereupon the dwarf laughed (the king was too confirmed a joker to object to any one's laughing), and displayed a set of large, powerful, and very repulsive teeth. Moreover, he avowed his perfect willingness to swallow as much wine as desired. The monarch was pacified; and having drained another bumper with no very perceptible ill effect, Hop-Frog entered at once, and with spirit, into the plans for the masquerade.  
  
"I cannot tell what was the association of idea," observed he, very tranquilly, and as if he had never tasted wine in his life, "but _just after_ your majesty, had struck the girl and thrown the wine in her face -- _just after_ your majesty had done this, and while the parrot was making that odd noise outside the window, there came into my mind a capital diversion -- one of my own country frolics -- often enacted among us, at our masquerades: but here it will be new altogether. Unfortunately, however, it requires a company of eight persons and-"  
  
"Here we _are_!" cried the king, laughing at his acute discovery of the coincidence; "eight to a fraction -- I and my seven ministers. Come! what is the diversion?"  
  
"We call it," replied the cripple, "the Eight Chained Ourang-Outangs, and it really is excellent sport if well enacted."  
  
"We will enact it," remarked the king, drawing himself up, and lowering his eyelids.  
  
"The beauty of the game," continued Hop-Frog, "lies in the fright it occasions among the women."  
  
"Capital!" roared in chorus the monarch and his ministry.  
  
"I will equip you as ourang-outangs," proceeded the dwarf; "leave all that to me. The resemblance shall be so striking, that the company of masqueraders will take you for real beasts -- and of course, they will be as much terrified as astonished."  
  
"Oh, this is exquisite!" exclaimed the king. "Hop-Frog! I will make a man of you."  
  
"The chains are for the purpose of increasing the confusion by their jangling. You are supposed to have escaped, _en masse_, from your keepers. Your majesty cannot conceive the _effect_ produced, at a masquerade, by eight chained ourang-outangs, imagined to be real ones by most of the company; and rushing in with savage cries, among the crowd of delicately and gorgeously habited men and women. The contrast is inimitable!"  
  
"It _must_ be," said the king: and the council arose hurriedly (as it was growing late), to put in execution the scheme of Hop-Frog.  
  
His mode of equipping the party as ourang-outangs was very simple, but effective enough for his purposes. The animals in question had, at the epoch of my story, very rarely been seen in any part of the civilized world; and as the imitations made by the dwarf were sufficiently beast-like and more than sufficiently hideous, their truthfulness to nature was thus thought to be secured.  
  
The king and his ministers were first encased in tight-fitting stockinet shirts and drawers. They were then saturated with tar. At this stage of the process, some one of the party suggested feathers; but the suggestion was at once overruled by the dwarf, who soon convinced the eight, by ocular demonstration, that the hair of such a brute as the ourang-outang was much more efficiently represented by flax. A thick coating of the latter was accordingly plastered upon the coating of tar. A long chain was now procured. First, it was passed about the waist of the king, and tied, then about another of the party, and also tied; then about all successively, in the same manner. When this chaining arrangement was complete, and the party stood as far apart from each other as possible, they formed a circle; and to make all things appear natural, Hop-Frog passed the residue of the chain in two diameters, at right angles, across the circle, after the fashion adopted, at the present day, by those who capture Chimpanzees, or other large apes, in Borneo.  
  
The grand saloon in which the masquerade was to take place, was a circular room, very lofty, and receiving the light of the sun only through a single window at top. At night (the season for which the apartment was especially designed) it was illuminated principally by a large chandelier, depending by a chain from the centre of the sky-light, and lowered, or elevated, by means of a counter-balance as usual; but (in order not to look unsightly) this latter passed outside the cupola and over the roof.  
  
The arrangements of the room had been left to Trippetta's superintendence; but, in some particulars, it seems, she had been guided by the calmer judgment of her friend the dwarf. At his suggestion it was that, on this occasion, the chandelier was removed. Its waxen drippings (which, in weather so warm, it was quite impossible to prevent) would have been seriously detrimental to the rich dresses of the guests, who, on account of the crowded state of the saloon, could not all be expected to keep from out its centre; that is to say, from under the chandelier. Additional sconces were set in various parts of the hall, out of the war, and a flambeau, emitting sweet odor, was placed in the right hand of each of the Caryatides that stood against the wall -- some fifty or sixty altogether.  
  
The eight ourang-outangs, taking Hop-Frog's advice, waited patiently until midnight (when the room was thoroughly filled with masqueraders) before making their appearance. No sooner had the clock ceased striking, however, than they rushed, or rather rolled in, all together -- for the impediments of their chains caused most of the party to fall, and all to stumble as they entered.  
  
The excitement among the masqueraders was prodigious, and filled the heart of the king with glee. As had been anticipated, there were not a few of the guests who supposed the ferocious-looking creatures to be beasts of _some_ kind in reality, if not precisely ourang-outangs. Many of the women swooned with affright; and had not the king taken the precaution to exclude all weapons from the saloon, his party might soon have expiated their frolic in their blood. As it was, a general rush was made for the doors; but the king had ordered them to be locked immediately upon his entrance; and, at the dwarf's suggestion, the keys had been deposited with _him_.  
  
While the tumult was at its height, and each masquerader attentive only to his own safety (for, in fact, there was much real danger from the pressure of the excited crowd), the chain by which the chandelier ordinarily hung, and which had been drawn up on its removal, might have been seen very gradually to descend, until its hooked extremity came within three feet of the floor.  
  
Soon after this, the king and his seven friends having reeled about the hall in all directions, found themselves, at length, in its centre, and, of course, in immediate contact with the chain. While they were thus situated, the dwarf, who had followed noiselessly at their heels, inciting them to keep up the commotion, took hold of their own chain at the intersection of the two portions which crossed the circle diametrically and at right angles. Here, with the rapidity of thought, he inserted the hook from which the chandelier had been wont to depend; and, in an instant, by some unseen agency, the chandelier-chain was drawn so far upward as to take the hook out of reach, and, as an inevitable consequence, to drag the ourang-outangs together in close connection, and face to face.  
  
The masqueraders, by this time, had recovered, in some measure, from their alarm; and, beginning to regard the whole matter as a well-contrived pleasantry, set up a loud shout of laughter at the predicament of the apes.  
  
"Leave them to me!" now screamed Hop-Frog, his shrill voice making itself easily heard through all the din. "Leave them to me. I fancy I know them. If I can only get a good look at them, I can soon tell who they are."  
  
Here, scrambling over the heads of the crowd, he managed to get to the wall; when, seizing a flambeau from one of the Caryatides, he returned, as he went, to the centre of the room-leaping, with the agility of a monkey, upon the kings head, and thence clambered a few feet up the chain; holding down the torch to examine the group of ourang-outangs, and still screaming: "I shall soon find out who they are!"  
  
And now, while the whole assembly (the apes included) were convulsed with laughter, the jester suddenly uttered a shrill whistle; when the chain flew violently up for about thirty feet -- dragging with it the dismayed and struggling ourang-outangs, and leaving them suspended in mid-air between the sky-light and the floor. Hop-Frog, clinging to the chain as it rose, still maintained his relative position in respect to the eight maskers, and still (as if nothing were the matter) continued to thrust his torch down toward them, as though endeavoring to discover who they were.  
  
So thoroughly astonished was the whole company at this ascent, that a dead silence, of about a minute's duration, ensued. It was broken by just such a low, harsh, grating sound, as had before attracted the attention of the king and his councillors when the former threw the wine in the face of Trippetta. But, on the present occasion, there could be no question as to whence the sound issued. It came from the fang-like teeth of the dwarf, who ground them and gnashed them as he foamed at the mouth, and glared, with an expression of maniacal rage, into the upturned countenances of the king and his seven companions.  
  
"Ah, ha!" said at length the infuriated jester. "Ah, ha! I begin to see who these people are now!" Here, pretending to scrutinize the king more closely, he held the flambeau to the flaxen coat which enveloped him, and which instantly burst into a sheet of vivid flame. In less than half a minute the whole eight ourang-outangs were blazing fiercely, amid the shrieks of the multitude who gazed at them from below, horror-stricken, and without the power to render them the slightest assistance.  
  
At length the flames, suddenly increasing in virulence, forced the jester to climb higher up the chain, to be out of their reach; and, as he made this movement, the crowd again sank, for a brief instant, into silence. The dwarf seized his opportunity, and once more spoke:  
  
"I now see distinctly." he said, "what manner of people these maskers are. They are a great king and his seven privy-councillors, -- a king who does not scruple to strike a defenceless girl and his seven councillors who abet him in the outrage. As for myself, I am simply Hop-Frog, the jester -- and this is my last jest."  
  
Owing to the high combustibility of both the flax and the tar to which it adhered, the dwarf had scarcely made an end of his brief speech before the work of vengeance was complete. The eight corpses swung in their chains, a fetid, blackened, hideous, and indistinguishable mass. The cripple hurled his torch at them, clambered leisurely to the ceiling, and disappeared through the sky-light.  
  
It is supposed that Trippetta, stationed on the roof of the saloon, had been the accomplice of her friend in his fiery revenge, and that, together, they effected their escape to their own country: for neither was seen again.